@@ -9,22 +9,16 @@
 
 ## IMPORTS ##
 
-import importlib
-import os
 import pytest
 import qsharp
 from qsharp.azure import AzureError, AzureJob, AzureTarget
-import sys
+from .utils import set_environment_variables
 
 ## SETUP ##
 
 @pytest.fixture(scope="session", autouse=True)
-def set_environment_variables():
-    # Need to restart the IQ# kernel after setting the environment variable
-    os.environ["AZURE_QUANTUM_ENV"] = "mock"
-    importlib.reload(qsharp)
-    if "qsharp.chemistry" in sys.modules:
-        importlib.reload(qsharp.chemistry)
+def session_setup():
+    set_environment_variables()
 
 ## TESTS ##
 
@@ -133,7 +127,7 @@ def _test_workspace_job_execution():
         qsharp.azure.execute(op)
     assert exception_info.value.error_name == "JobSubmissionFailed"
 
-    histogram = qsharp.azure.execute(op, count=3, name="test", timeout=3, poll=0.5)
+    histogram = qsharp.azure.execute(op, count=3, name="test", timeout=3, poll=2)
     assert isinstance(histogram, dict)
 
     retrieved_histogram = qsharp.azure.output()
